(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23655,        684]*)
(*NotebookOutlinePosition[    113987,       3691]*)
(*  CellTagsIndexPosition[    113904,       3685]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], " ", 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[" PDEs", "Subsection",
  TextAlignment->Center],

Cell[TextData[{
  "Modelling with PDEs is appropriate for continuous models and is becoming \
more prevalant as numerical solution without supercomputers is becoming more \
realistic.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " provides a general PDE solver that is appropriate for evolution \
equations."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Fishers\ equation\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
This is a reaction-diffusion equation modelling population spread \
via diffusion with population limits.\
\>", "Text"],

Cell[TextData[{
  "As an illustration of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s numerical capabilities, consider the following problem:\n(From \"A \
short course in Mathematical Biology\", G. deVries, T; Hillen, M. Lewis, J. \
Muller, B Schonfish\nSIAM)"
}], "Text"],

Cell["\<\
A Dingo population, which lives in eastern parts of Australia is \
prevented from invasion to teh west by a fence which runs north-south.  In \
this exercise we study the case that the fence breaks somewhere.\
\>", "Text"],

Cell["\<\
Two farms, A and B are located on the west side of the fence.  The \
distance of fram A to the fence is 100 miles and the distance from farm A to \
farm B is another 100 miles.  The farmers want to know how long it takes \
until the Dingo population reaches their farms.  We model the spread of the \
Dingo population with Fishers equation\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`u\_t \[LongEqual] 
      D\ u\_xx\  + \ \ \(\(u\)\(\ \)\((1 - u)\)\(\ \)\)\)], "Input"],

Cell[TextData[{
  "1. The region between A and the fence is flat and the diffusion constant \
is ",
  Cell[BoxData[
      \(TraditionalForm\`d\_1 = \ 100\)]]
}], "Text"],

Cell[TextData[{
  "2. The region between A and B has rocks and slope and the diffusion \
constant is ",
  Cell[BoxData[
      \(TraditionalForm\`d\_2\  = \ 50\)]]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Fishers\ equation\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[TextData[{
  "1. The region between A and the fence is flat and the diffusion constant \
is ",
  Cell[BoxData[
      \(TraditionalForm\`d\_1 = \ 100\)]]
}], "Text"],

Cell[TextData[{
  "2. The region between A and B has rocks and slope and the diffusion \
constant is ",
  Cell[BoxData[
      \(TraditionalForm\`d\_2\  = \ 50\)]]
}], "Text"],

Cell["First define the diffusion as a function of x.", "Text"],

Cell[BoxData[{
    \(\(Clear[d];\)\), "\[IndentingNewLine]", 
    \(\(d[x_\  /; \ 100\  \[LessEqual] \ x \[LessEqual] \ 200]\  = \ 
        10;\)\), "\[IndentingNewLine]", 
    \(\(d[x_?NumberQ]\  = \ 100;\)\)}], "Input",
  CellLabel->"In[85]:="],

Cell[TextData[{
  "Here is the equation in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " input form for a computational domain of length 300."
}], "Text"],

Cell[BoxData[
    \(\(feqn\  = {D[u[t, x], t]\  \[Equal] \ 
            d[x]\ D[u[t, x], x, x]\  + \ 
              u[t, x] \((1\  - \ u[t, x])\), \[IndentingNewLine]u[0, 
              x]\  \[Equal] \ UnitStep[\(-x\)], \ u[t, 0]\  \[Equal] \ 1, \ 
          u[t, \ 300]\  \[Equal] \ 0};\)\)], "Input",
  CellLabel->"In[88]:="],

Cell["\<\
Now take a look at a simple numerical solution of the \
equation\
\>", "Text"],

Cell[BoxData[
    \(T\  = \ 25; 
    sol\  = \ First[NDSolve[feqn, \ u, \ {t, 0, T}, {x, 0, 300}]]\)], "Input",\

  CellLabel->"In[89]:="],

Cell[BoxData[
    \(Do[Plot[u[t, x]\  /. \ sol, {x, 0, 300}, \ PlotRange \[Rule] All], {t, 
        0, 14}]\)], "Input",
  CellLabel->"In[91]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Improving\ the\ solution\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell["\<\
NDSolve chooses a grid, but when the initial condition is \
discontinuous, the methods used to make the choice do not work optimally.  In \
this case, it is often appropriate to specify a particular spatial grid or \
grid spacing.  \
\>", "Text"],

Cell[BoxData[
    \(dx\  = \  .25; 
    Timing[sol\  = \ 
        First[NDSolve[feqn, \ u, \ {t, 0, 25}, {x, 0, 300}, 
            Method \[Rule] {"\<MethodOfLines\>", \ \
"\<SpatialDiscretization\>" \[Rule] {"\<TensorProductGrid\>", \ 
                    MaxStepSize \[Rule] dx}}]]]\)], "Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \(Do[Plot[u[t, x]\  /. \ sol, {x, 0, 300}, \ PlotRange \[Rule] All], {t, 
        0, T}]\)], "Input",
  CellLabel->"In[93]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Wave\ speed\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[BoxData[
    \(xh[t_?NumberQ]\  := \ 
      x\  /. \ FindRoot[
          Evaluate[\((u[t, x]\  /. \ sol)\)\  - \ 1/2], {x, 0, 
            300}]\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(\(Plot[xh[t], \ {t, 0, T}];\)\)], "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    \(\[Epsilon]\  = \  .01; 
    Plot[\((xh[t\  + \ \[Epsilon]]\  - \ xh[t\  - \ \[Epsilon]])\)/
          2  \[Epsilon], {t, \[Epsilon], T\  - \ \[Epsilon]}, \ 
      PlotRange \[Rule] All];\)], "Input",
  CellLabel->"In[96]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Arrival\ time\ as\ an\ event\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Alpha]\  = \ 0.5; dx\  = \  .25; 
    sol\  = \ First[
        NDSolve[feqn, \ u, \ {t, 0, T}, {x, 0, 300}, 
          Method \[Rule] {"\<MethodOfLines\>", \ "\<SpatialDiscretization\>" \
\[Rule] {"\<TensorProductGrid\>", \ MaxStepSize \[Rule] dx}, 
              Method \[Rule] {EventLocator, \ "\<Event\>" \[Rule] {u[t, 
                          100]\  - \ \[Alpha], 
                      u[t, 200]\  - \ \[Alpha]}, \ "\<EventAction\>" \
\[RuleDelayed] \ {Print["\<Arrival at farm A in \>", t, "\< months\>"], 
                      Print["\<Arrival at farm B in \>", 
                        t, "\< months\>"]}}}]]\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    InterpretationBox[\("Arrival at farm A in \
"\[InvisibleSpace]8.259105788369947`\[InvisibleSpace]" months"\),
      SequenceForm[ "Arrival at farm A in ", 8.259105788369947, " months"],
      Editable->False]], "Print",
  CellLabel->"From In[97]:="],

Cell[BoxData[
    InterpretationBox[\("Arrival at farm B in \
"\[InvisibleSpace]23.90496580137512`\[InvisibleSpace]" months"\),
      SequenceForm[ "Arrival at farm B in ", 23.90496580137512, " months"],
      Editable->False]], "Print",
  CellLabel->"From In[97]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"u", "\[Rule]", 
        TagBox[\(InterpolatingFunction[{{0.`, 25.`}, {0.`, 300.`}}, "<>"]\),
          False,
          Editable->False]}], "}"}]], "Output",
  CellLabel->"Out[97]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox["\[FirstPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageFirst"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"First Slide"], 
          ButtonBox[
            StyleBox["\[LeftPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPagePrevious"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Previous Slide"], 
          ButtonBox[
            StyleBox["\[RightPointer]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageNext"]}],
            ButtonStyle->"SlideHyperlink",
            ButtonNote->"Next Slide"], 
          ButtonBox[
            StyleBox["\[LastPage]",
              "SR"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEndToken[ 
                  FrontEnd`SelectedNotebook[ ], "ScrollPageLast"]}],
            ButtonStyle->"SlideHyperlink"], 
          StyleBox[\(Diffusion\ over\ area\),
            "Text",
            FontSize->16,
            FontWeight->"Bold"], 
          ButtonBox[
            StyleBox[
              RowBox[{
                CounterBox["SlideShowNavigationBar"], \(\(\ \)\(of\)\(\ \)\), 
                
                
                CounterBox["SlideShowNavigationBar", {None, 
                  "SlideShowHeader", -1}]}],
              "SR"],
            ButtonFrame->"None"]}
        }]]]], "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[BoxData[{
    \(\(d2\  = \ 100;\)\), "\[IndentingNewLine]", 
    \(\(s\  = \  .001;\)\), "\[IndentingNewLine]", 
    \(\(L\  = \ 200;\)\), "\[IndentingNewLine]", 
    \(\(T\  = \ 10;\)\), "\[IndentingNewLine]", 
    \(\(f2d\  = {D[u[t, x, y], t]\  \[Equal] \ 
            d2\ \((D[u[t, x, y], x, x]\ \  + \ D[u[t, x, y], \ y, y])\) + 
              u[t, x, y] \((1\  - \ u[t, x, y])\), \[IndentingNewLine]u[0, x, 
              y]\  \[Equal] \ 
            Exp[\(-s\) \((x^2\  + \ y^2)\)], \ \ \((D[u[t, x, y], x]\  /. \ 
                x \[Rule] 0)\) \[Equal] \ 0, u[t, L, \ y]\  \[Equal] \ 0, \ 
          u[t, x, \ \(-L\)]\  \[Equal] \ u[t, x, L]\  \[Equal] \ 
            0};\)\)}], "Input",
  CellLabel->"In[111]:="],

Cell["\<\
Because the 1 + 2 dimensional problem takes a little while to \
compute, it is nice to set up a monitor to show the solution as it is being \
computed:\
\>", "Text"],

Cell[BoxData[
    \(\[CapitalDelta]t\  = \  .25; \  (*\ 
      Interval\ between\ frames\ *) \[IndentingNewLine]action\  := \ \((\
\[IndentingNewLine]timem\  = \ 
          StringJoin["\<t = \>", \ 
            ToString[Round[t/60]], \ "\<min  RAM in use = \>", 
            ToString[ .1 
                 Round[MemoryInUse[]/
                    10^5]], \ "\< MB\>"]; \[IndentingNewLine]monitor\ @\ 
          SetPropertyValue[{"\<time\>", \ "\<text\>"}, 
            timem]; \[IndentingNewLine]monitor\ @\ 
          InvokeMethod[{"\<imagePanel\>", "\<setData\>"}, \
\[IndentingNewLine]ExportString[\ 
              ListPlot3D[u[t, \ x, \ y], \ Mesh \[Rule] False, 
                PlotRange \[Rule] {0, 1}, 
                DisplayFunction \[Rule] \ 
                  Identity], \ "\<GIF\>"]]; \[IndentingNewLine]If[\ 
          TrueQ[\ monitor\ @\ Script[stopRequested]], \ 
          monitor\ @\ Script[stopRequested\  = \ False]; 
          Throw[Null, \ "\<StopIntegration\>"]];\[IndentingNewLine])\)\)], \
"Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(\(monitor\  = \ GUIRun[monitorwidget];\)\)], "Input",
  CellLabel->"In[119]:="],

Cell["This solves the PDE", "Text"],

Cell[BoxData[
    \(sol\  = \ 
      First[NDSolve[f2d, \ u, {t, \ 0, \ T}, \ {x, 0, L}, {y, \(-L\), \ L}, \ 
          Method \[Rule] {MethodOfLines, \ "\<SpatialDiscretization\>" \
\[Rule] {"\<TensorProductGrid\>", MinPoints \[Rule] {80, \ 80}, \ 
                  MaxPoints \[Rule] {80, 
                      80}}, \[IndentingNewLine]"\<DiscretizedMonitorVariables\
\>" \[Rule] 
                True, \[IndentingNewLine]Method \[Rule] {"\<EventLocator\>", \
\ "\<Event\>" -> 
                    Sin[\[Pi]\ t/\[CapitalDelta]t], \ "\<EventAction\>" \
\[RuleDelayed] action}}]]\)], "Input",
  CellLabel->"In[120]:="],

Cell["This plots the solution.", "Text"],

Cell[BoxData[
    \(Do[Plot3D[
        Evaluate[u[t, x, y]\  /. \ sol], \ {x, 0, L}, {y, \(-L\), L}, \ 
        PlotRange \[Rule] {0, 1}], {t, 0, T}]\)], "Input",
  CellLabel->"In[347]:="]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 967}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"SlideShow",
WindowToolbars->{},
WindowSize->{1392, 933},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
ShowSelection->True,
CellLabelAutoDelete->False,
InputAliases->{"intt"->RowBox[ {"\[Integral]", 
        RowBox[ {"\[SelectionPlaceholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "dintt"->RowBox[ {
        SubsuperscriptBox[ 
        "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
        RowBox[ {"\[Placeholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "sumt"->RowBox[ {
        UnderoverscriptBox[ "\[Sum]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "prodt"->RowBox[ {
        UnderoverscriptBox[ "\[Product]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "dt"->RowBox[ {
        SubscriptBox[ "\[PartialD]", "\[Placeholder]"], " ", 
        "\[SelectionPlaceholder]"}], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Wolfram Technology Conference 2004", "Title"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Color"->RGBColor[0.269993, 0.308507, 0.6]},
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True,
    "VerticalScrollRange"->Fit},
    ShowCellBracket->False,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{27, Inherited}, {10, 30}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 11},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->RGBColor[0.286275, 0.294118, 0.627451]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{27, 50}, {10, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Title", "SlideShow"],
    CellMargins->{{100, 50}, {10, 80}}],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{27, Inherited}, {20, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{27, 50}, {20, 2}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "SlideShow"],
    CellMargins->{{100, 50}, {30, 2}}],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{27, Inherited}, {8, 2}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "SlideShow"],
    CellMargins->{{100, 25}, {30, 10}}],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{27, Inherited}, {8, 34}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->4,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 2},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold",
    FontColor->RGBColor[0.286275, 0.294118, 0.627451]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 50}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "SlideShow"],
    CellMargins->{{100, 50}, {11, 35}}],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 0}, {7, 22}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{60, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.286275, 0.294118, 0.627451]],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{72, 50}, {6, 15}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "SlideShow"],
    CellMargins->{{100, 50}, {8, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 0}, {8, 22}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{60, Inherited}, {2, 10}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->RGBColor[0.286275, 0.294118, 0.627451]],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{72, 50}, {6, 12}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "SlideShow"],
    CellMargins->{{100, 50}, {6, 12}}],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {7, 14}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{20, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Helvetica"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{72, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "SlideShow"],
    CellMargins->{{20, 50}, {10, 10}},
    FontSize->16],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{60, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 50}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->10],
  
  Cell[StyleData["SmallText", "SlideShow"],
    CellMargins->{{100, 50}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->10],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->7]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{66, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, 50}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {8, 10}},
    ShowCellLabel->False,
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellMargins->{{66, 10}, {7, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Mathematica",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InputOnly", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["InputOnly", "SlideShow"],
    CellMargins->{{100, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{66, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, 50}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "SlideShow"],
    ShowCellBracket->True,
    CellMargins->{{100, 50}, {10, 8}},
    ShowCellLabel->False,
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0.6, 0.100008, 0.100008]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Message", "SlideShow"],
    CellMargins->{{100, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{66, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Print", "SlideShow"],
    CellMargins->{{100, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "SlideShow"],
    ShowCellBracket->True,
    ImageMargins->{{100, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0.392157, 0.396078, 0.717647]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "SlideShow"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FrameLabel"],
    LanguageCategory->None,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["FrameLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["FrameLabel", "SlideShow"],
    FontSize->12],
  
  Cell[StyleData["FrameLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Presentation Specific", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellMargins->{{30, 10}, {7, 7}},
    CellFrameLabels->{{
      Cell[ "\[Bullet]", "BulletedList", CellBaseline -> Baseline], 
          Inherited}, {Inherited, Inherited}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"BulletedList",
    FontFamily->"Helvetica"],
  
  Cell[StyleData["BulletedList", "Presentation"],
    CellMargins->{{62, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["BulletedList", "SlideShow"],
    CellMargins->{{30, 50}, {10, 10}},
    FontSize->16],
  
  Cell[StyleData["BulletedList", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{100, 27}, {2, 20}},
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{200, 27}, {2, 50}},
    FontSize->28],
  
  Cell[StyleData["Author", "SlideShow"],
    CellMargins->{{200, 27}, {2, 50}},
    FontSize->28],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{100, 27}, {2, 20}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Affiliation"],
    CellMargins->{{100, 27}, {30, 12}},
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Affiliation", "Presentation"],
    CellMargins->{{200, 27}, {2, 10}},
    FontSize->28],
  
  Cell[StyleData["Affiliation", "SlideShow"],
    CellMargins->{{200, 27}, {2, 10}},
    FontSize->28],
  
  Cell[StyleData["Affiliation", "Printout"],
    CellMargins->{{100, 27}, {2, 12}},
    FontSize->14]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Header Graphic", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ConferenceGraphicCell"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    Evaluatable->False,
    PageBreakBelow->False,
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}},
    Background->GrayLevel[1],
    Magnification->1],
  
  Cell[StyleData["ConferenceGraphicCell", "Presentation"]],
  
  Cell[StyleData["ConferenceGraphicCell", "SlideShow"]],
  
  Cell[StyleData["ConferenceGraphicCell", "Printout"],
    FontSize->8,
    Magnification->0.75]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "SlideShow"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{60, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "SlideShow"],
    CellMargins->{{100, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Outline Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline1"],
    CellMargins->{{60, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 50},
    ParagraphIndent->-38,
    CounterIncrements->"Outline1",
    CounterAssignments->{{"Outline2", 0}, {"Outline3", 0}, {"Outline4", 0}},
    FontSize->18,
    FontWeight->"Bold",
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}],
  
  Cell[StyleData["Outline1", "SlideShow"]],
  
  Cell[StyleData["Outline1", "Printout"],
    CounterBoxOptions->{
    CounterFunction:>Utilities`Notation`Private`CapitalRomanNumeral}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline2"],
    CellMargins->{{90, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 60},
    ParagraphIndent->-27,
    CounterIncrements->"Outline2",
    CounterAssignments->{{"Outline3", 0}, {"Outline4", 0}},
    FontSize->15,
    FontWeight->"Bold",
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}],
  
  Cell[StyleData["Outline2", "SlideShow"]],
  
  Cell[StyleData["Outline2", "Printout"],
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "A", "Z"], #]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline3"],
    CellMargins->{{120, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 70},
    ParagraphIndent->-21,
    CounterIncrements->"Outline3",
    CounterAssignments->{{"Outline4", 0}},
    FontSize->12,
    CounterBoxOptions->{CounterFunction:>Identity}],
  
  Cell[StyleData["Outline3", "SlideShow"]],
  
  Cell[StyleData["Outline3", "Printout"],
    CounterBoxOptions->{CounterFunction:>Identity}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Outline4"],
    CellMargins->{{150, 10}, {7, 7}},
    CellGroupingRules->{"SectionGrouping", 80},
    ParagraphIndent->-18,
    CounterIncrements->"Outline4",
    FontSize->10,
    CounterBoxOptions->{CounterFunction:>(Part[ 
        CharacterRange[ "a", "z"], #]&)}],
  
  Cell[StyleData["Outline4", "SlideShow"]],
  
  Cell[StyleData["Outline4", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "SlideShow"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "SlideShow"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "SlideShow"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "SlideShow"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLinkText", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLinkText", "SlideShow"]],
  
  Cell[StyleData["RefGuideLinkText", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "SlideShow"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "SlideShow"]],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "SlideShow"]],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "SlideShow"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "SlideShow"]],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, Placeholder]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "SlideShow"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "SlideShow"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    LanguageCategory->"Formula",
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]],
  
  Cell[StyleData["Completions"],
    StyleMenuListing->None,
    FontFamily->"Courier"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles from HelpBrowser", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{66, 12}, {2, 24}},
    PageBreakBelow->False,
    CellFrameMargins->{{8, 8}, {8, 2}},
    CellFrameColor->GrayLevel[0.700008],
    CellFrameLabelMargins->4,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    StyleMenuListing->None,
    FontColor->GrayLevel[0.2]],
  
  Cell[StyleData["MathCaption", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MathCaption", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{39, 0}, {0, 14}},
    Hyphenation->True,
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ObjectName"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["ObjectName", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ObjectName", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["ObjectName", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Usage"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Usage", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Usage", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Usage", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notes"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["Notes", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Notes", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Notes", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineOutput"],
    ShowCellBracket->True,
    CellMargins->{{66, 4}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelAutoDelete->False,
    CellLabelMargins->{{14, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    ShowSpecialCharacters->Automatic,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Mathematica",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineOutput", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["InlineOutput", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineOutput", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{39, 0}, {6, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Box", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DoubleBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["1ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.31, 0.67}}],
  
  Cell[StyleData["2ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnSmallBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.32}],
  
  Cell[StyleData["3ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnSmallBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    SingleLetterItalics->False,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.13, 0.35, 0.13, 0.35}}],
  
  Cell[StyleData["4ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["4ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->0.202}],
  
  Cell[StyleData["5ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["5ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxFrame->0.5,
    BoxMargins->True},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["6ColumnBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["FramedBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["FramedBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["FramedBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["FramedBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.4, 0.6},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.35, 0.2, 0.45},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox3Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox3Col", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox4Col", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox5Col", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["DefinitionBox6Col", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 2}},
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{27, 12}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["BottomBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 0}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->2.2}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{27, 12}, {-2, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TopSpanBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-2, 8}},
    FontSize->10,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{27, 12}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakAbove->False,
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["MiddleSpanBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 0}, {-5, 0}},
    FontSize->10,
    Background->GrayLevel[1],
    GridBoxOptions->{RowMinHeight->1.8}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{27, Inherited}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Picture", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {4, 4}},
    Magnification->0.65]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OpenCloseItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    PrivateCellOptions->{"DefaultCellGroupOpen"->False},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["OpenCloseItemizedPicture", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["OpenCloseItemizedPicture", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ItemizedPicture", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListGraphic"],
    CellMargins->{{88, 4}, {4, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ListGraphic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListGraphic", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["ListGraphic", "Printout"],
    CellMargins->{{77, 2}, {4, -4}},
    Magnification->0.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ListNoteBox"],
    CellFrame->0.5,
    CellMargins->{{88, 12}, {8, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0.74902, 0.694118, 0.552941],
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[0.964706, 0.929412, 0.839216],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ListNoteBox", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ListNoteBox", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["ListNoteBox", "Printout"],
    CellMargins->{{77, 4}, {6, 2}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{41, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["PictureGroup", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{76, 2}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    ShowCellBracket->True,
    CellMargins->{{27, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Sound", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnTable", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["2ColumnEvenTable", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{35, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["3ColumnTable", "SlideShow"],
    CellMargins->{{100, 50}, {Inherited, Inherited}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    FontSize->9]
  }, Closed]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 50}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 0},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.850004],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 40, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Presentation"],
    FontSize->10,
    Magnification->1],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellOpen->False,
    FontSize->1]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    CellFrameMargins->{{20, 10}, {10, 18}},
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "Presentation"],
    CellMargins->{{14, 10}, {6, 12}}],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlidePreviousNextLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    FontSize->12,
    FontColor->GrayLevel[0.500008],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlidePreviousNextLink", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["SlidePreviousNextLink", "SlideShow"]],
  
  Cell[StyleData["SlidePreviousNextLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PreviousNext"],
    CellMargins->{{60, 10}, {7, 7}},
    TextAlignment->0.75,
    LineSpacing->{1, 3},
    CounterIncrements->"PreviousNext",
    FontFamily->"Helvetica",
    FontSize->12,
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["PreviousNext", "Presentation"],
    CellMargins->{{24, 50}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["PreviousNext", "SlideShow"],
    CellMargins->{{50, 50}, {50, 15}},
    FontSize->14],
  
  Cell[StyleData["PreviousNext", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    Hyphenation->True,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "Presentation"],
    CellMargins->{{35, 10}, {8, 8}},
    FontSize->18],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "Presentation"],
    CellMargins->{{25, 10}, {10, 5}},
    FontSize->18],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "SlideShowHeader"->{
    Cell[1776, 53, 1679, 44, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[3917, 118, 1796, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[7250, 217, 1796, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[10626, 324, 1803, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[13197, 398, 1790, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[15551, 469, 1807, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"],
    Cell[18883, 561, 1800, 48, 20, "SlideShowNavigationBar",
      CellTags->"SlideShowHeader"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"SlideShowHeader", 113203, 3666}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 1679, 44, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[CellGroupData[{
Cell[3480, 101, 52, 1, 59, "Subsection"],
Cell[3535, 104, 333, 8, 130, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3917, 118, 1796, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[5716, 168, 129, 3, 63, "Text"],
Cell[5848, 173, 288, 7, 130, "Text"],
Cell[6139, 182, 232, 4, 96, "Text"],
Cell[6374, 188, 363, 6, 129, "Text"],
Cell[6740, 196, 124, 2, 56, "Input"],
Cell[6867, 200, 169, 5, 63, "Text"],
Cell[7039, 207, 174, 5, 63, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7250, 217, 1796, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[9049, 267, 169, 5, 63, "Text"],
Cell[9221, 274, 174, 5, 63, "Text"],
Cell[9398, 281, 62, 0, 63, "Text"],
Cell[9463, 283, 246, 5, 125, "Input"],
Cell[9712, 290, 167, 5, 64, "Text"],
Cell[9882, 297, 327, 6, 91, "Input"],
Cell[10212, 305, 88, 3, 63, "Text"],
Cell[10303, 310, 138, 4, 57, "Input"],
Cell[10444, 316, 145, 3, 57, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10626, 324, 1803, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[12432, 374, 256, 5, 96, "Text"],
Cell[12691, 381, 322, 7, 193, "Input"],
Cell[13016, 390, 144, 3, 57, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13197, 398, 1790, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[14990, 448, 187, 5, 57, "Input"],
Cell[15180, 455, 87, 2, 57, "Input"],
Cell[15270, 459, 244, 5, 57, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15551, 469, 1807, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],

Cell[CellGroupData[{
Cell[17383, 521, 679, 12, 295, "Input"],
Cell[18065, 535, 267, 5, 38, "Print"],
Cell[18335, 542, 267, 5, 38, "Print"],
Cell[18605, 549, 229, 6, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18883, 561, 1800, 48, 20, "SlideShowNavigationBar",
  CellTags->"SlideShowHeader"],
Cell[20686, 611, 727, 13, 329, "Input"],
Cell[21416, 626, 175, 4, 96, "Text"],
Cell[21594, 632, 1049, 21, 397, "Input"],
Cell[22646, 655, 99, 2, 57, "Input"],
Cell[22748, 659, 35, 0, 63, "Text"],
Cell[22786, 661, 619, 12, 193, "Input"],
Cell[23408, 675, 40, 0, 63, "Text"],
Cell[23451, 677, 188, 4, 91, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

